Instruction:
You need to provide multiple possible solutions based on the given problem, with each solution utilizing a different type of knowledge.
Requirements:
1.The types of knowledge include three: chunk, graph, table, algorithm, catalogue
2.Your proposed solutions need to clarify how to construct the document from the current task into the corresponding type of knowledge, and how to use that type of knowledge to answer the questions in the task.
3.Follow the output format in the Examples, with each solution on a separate line, and each solution beginning with the chosen type of knowledge.
Examples:
########
Query:
Based on the documents above, summarize the development trends of this company over the past two years.
Output:
1.Chunk: To build and use chunk-type knowledge, I first need to break these financial reports into multiple independent chunks. Then, based on the query, I will select a few chunks that best reflect the company’s
development trends. Finally, I will summarize the company's development trends over the past two years based on the information from the selected chunks.
2.Graph: To build and use graph-type knowledge, I need to present the information from the documents in the form of a graph, with the company name as the head node, financial metrics as the relationships, and c
orresponding financial data as the tail nodes. Then, I will find the relevant company and subgraph based on the query and summarize the company's development trends over the past two years based on the informa
tion in the subgraph.
3.Table: To build and use table-type knowledge, I need to present the information from the documents in table form, with the company name as the rows and various financial metrics as the columns. The value in e
ach cell will be the corresponding financial data. Finally, I will summarize the company's development trends over the past two years based on the information in the table.
4.Algorithm: To build and use algorithm-type knowledge, I need to use the company’s metrics as judgment criteria, with each decision in the process determining whether to consider the information from that metr
ic. Ultimately, I will summarize the company's development trends based on this process.
5.Catalogue: To build and use catalogue-type knowledge, I need to classify the company’s different financial metrics by importance. Each level of the directory will include specific information about the metric, an
d I will draw conclusions based on all the metric information in this catalogue.
########
Query:
{{query}}
Output: